@@ -518,7 +518,6 @@ class GTKUI : public GUI, public MetaDataUI
         int         fTop;
         GtkWidget*  fBox[kStackSize];
         int         fMode[kStackSize];
-        bool        fStopped;
     
         GtkWidget* addWidget(const char* label, GtkWidget* w);
         virtual void pushBox(int mode, GtkWidget* w);
@@ -579,8 +578,8 @@ class GTKUI : public GUI, public MetaDataUI
         virtual void addNumDisplay(const char* label, FAUSTFLOAT* zone, int precision);
         virtual void addTextDisplay(const char* label, FAUSTFLOAT* zone, const char* names[], FAUSTFLOAT min, FAUSTFLOAT max);
     
-        virtual void show();
         virtual bool run();
+        virtual void stop();
     
 };
 
@@ -621,7 +620,6 @@ GTKUI::GTKUI(char * name, int* pargc, char*** pargv)
     fTop = 0;
     fBox[fTop] = gtk_vbox_new(homogene, 4);
     fMode[fTop] = kBoxMode;
-    fStopped = false;
 }
 
 // Stack a box
@@ -846,7 +844,7 @@ GtkWidget* GTKUI::addWidget(const char* label, GtkWidget* w)
         case kBoxMode       : gtk_box_pack_start(GTK_BOX(fBox[fTop]), w, expand, fill, 0);                 break;
         case kTabMode       : gtk_notebook_append_page(GTK_NOTEBOOK(fBox[fTop]), w, gtk_label_new(label)); break;
     }
-    gtk_widget_show (w);
+    gtk_widget_show(w);
     return w;
 }
 
@@ -1342,13 +1340,6 @@ void GTKUI::addTextDisplay(const char* label, FAUSTFLOAT* zone, const char* name
     checkForTooltip(zone, lw);
 }
 
-void GTKUI::show()
-{
-    assert(fTop == 0);
-    gtk_widget_show(fBox[0]);
-    gtk_widget_show(fWindow);
-}
-
 /**
  * Update all user items reflecting zone z
  */
@@ -1391,10 +1382,16 @@ bool GTKUI::run()
     
     gtk_timeout_add(40, callUpdateAllGuis, 0);
     gtk_main();
-    stop();
     return true;
 }
 
+void GTKUI::stop()
+{
+    GUI::stop();
+    gtk_main_quit();
+    gtk_signal_emit_by_name((GtkObject*)fWindow, "destroy");
+}
+
 #endif
 
 /**************************  END  GTKUI.h **************************/
